@@ -11,7 +11,7 @@ except ImportError:  # TODO: Remove when dropping Django releases < 3.1
     from django.contrib.postgres.fields import JSONField
 from django.contrib.postgres.indexes import GinIndex
 from django.db import models
-from django.db.models import UniqueConstraint, Q
+from django.db.models import CheckConstraint, UniqueConstraint, Q
 from django.utils.functional import cached_property
 from django.utils.text import slugify
 from django.utils.translation import gettext_lazy as _
@@ -272,6 +272,7 @@ class CrudViewProperty(models.Model):
     include_in_tile = models.BooleanField(default=False, db_index=True)
     required = models.BooleanField(default=False, db_index=True)
     order = models.PositiveSmallIntegerField(default=0, db_index=True)
+    editable = models.BooleanField(default=True)
 
     class Meta:
         unique_together = (
@@ -284,10 +285,23 @@ class CrudViewProperty(models.Model):
             GinIndex(name='json_schema_index', fields=['json_schema'], opclasses=['jsonb_path_ops']),
             GinIndex(name='ui_schema_index', fields=['ui_schema'], opclasses=['jsonb_path_ops']),
         )
+        constraints = [
+            CheckConstraint(check=(
+                Q(required=True, editable=True)
+                | Q(required=False, editable=True)
+                | Q(required=False, editable=False)),
+                name='check_required_editable'),
+        ]
 
     def __str__(self):
         return f"{self.title} ({self.key})"
 
+    def clean(self):
+        if self.required and not self.editable:
+            raise ValidationError(
+                _("Property cannot be required but not editable")
+            )
+
     @property
     def title(self):
         """ Title: ui schema -> json schema -> key capitalized """
@@ -371,10 +385,10 @@ class RoutingSettings(models.Model):
             ('layer', 'crud_view'),
         )
         constraints = [
-            UniqueConstraint(fields=['provider', 'layer'], condition=Q(layer__isnull=False),
+            UniqueConstraint(fields=['provider', 'layer', 'crud_view'], condition=Q(layer__isnull=False),
                              name='check_provider_layer'
                              ),
-            UniqueConstraint(fields=['provider', 'mapbox_transit'], condition=~Q(mapbox_transit=''),
+            UniqueConstraint(fields=['provider', 'mapbox_transit', 'crud_view'], condition=~Q(mapbox_transit=''),
                              name='check_provider_mapbox_transit'
                              ),
         ]
@@ -400,11 +414,13 @@ class RoutingSettings(models.Model):
             raise ValidationError(
                 _("You should define a layer with this provider")
             )
-        if RoutingSettings.objects.filter(Q(mapbox_transit=self.mapbox_transit) & ~Q(mapbox_transit='')).exclude(label=self.label):
+        if RoutingSettings.objects.filter(Q(mapbox_transit=self.mapbox_transit) & ~Q(mapbox_transit=''),
+                                          crud_view=self.crud_view).exclude(label=self.label):
             raise ValidationError(
                 _("This transit is already used")
             )
-        if RoutingSettings.objects.filter(Q(layer=self.layer) & Q(layer__isnull=False)).exclude(label=self.label):
+        if RoutingSettings.objects.filter(Q(layer=self.layer) & Q(layer__isnull=False),
+                                          crud_view=self.crud_view).exclude(label=self.label):
             raise ValidationError(
                 _("This layer is already used")
             )
