@@ -22,7 +22,7 @@ class FormSchemaMixin:
         # add default other properties
         remained_properties = list(self.properties.filter(group__isnull=True).values_list('key', flat=True))
         for prop in remained_properties:
-            generated_schema['properties'][prop] = original_schema['properties'][prop]
+            generated_schema['properties'][prop] = original_schema.get('properties', {}).get(prop)
 
         return generated_schema
 
@@ -33,7 +33,7 @@ class FormSchemaMixin:
         """
         ui_schema = deepcopy(self.ui_schema)
 
-        groups = self.feature_display_groups.all()
+        groups = self.feature_display_groups.all().prefetch_related('group_properties')
         for group in groups:
             # each field defined in ui schema should be placed in group key
             ui_schema[group.slug] = {'ui:order': []}
@@ -57,11 +57,15 @@ class FormSchemaMixin:
 
 def sync_layer_schema(crud_view):
     """ sync layer schema with properties defined by crud view properties """
-    properties = crud_view.properties.all()
-    crud_view.layer.schema = {"properties": {
-        prop.key: prop.json_schema for prop in properties
-    }, 'required': list(properties.filter(required=True).values_list('key', flat=True))}
-    # required fields
+    properties = crud_view.properties.all().prefetch_related('values')
+    crud_view.layer.schema = {
+        "properties": {
+            prop.key: prop.full_json_schema for prop in properties
+        },
+        # required fields
+        'required': list(properties.filter(required=True).values_list('key', flat=True))
+    }
+
     crud_view.layer.save()
 
 
@@ -90,3 +94,12 @@ def clean_properties_not_in_schema_or_null(crud_view):
                     properties.pop(prop, 0)
             feat.properties = properties
             feat.save()
+
+
+def sync_properties_in_tiles(crud_view):
+    property_keys = list(crud_view.properties.filter(include_in_tile=True).values_list('key', flat=True))
+    settings = crud_view.layer.settings
+    settings_tiles = settings.get('tiles', {})
+    settings_tiles.update({'properties_filter': property_keys if property_keys else None})
+    settings['tiles'] = settings_tiles
+    crud_view.layer.save()
