@@ -174,8 +174,8 @@ class FeatureDisplayPropertyGroup(serializers.ModelSerializer):
             prop.key: feature.properties.get(prop.key)
             for prop in obj.group_properties.all()
         }
-
-        return serialize_group_properties(feature, final_properties)
+        editable = {prop.key: prop.editable for prop in obj.group_properties.all()}
+        return serialize_group_properties(feature, final_properties, editable)
 
     class Meta:
         model = models.FeaturePropertyDisplayGroup
@@ -203,6 +203,14 @@ class CrudFeatureListSerializer(BaseUpdatableMixin, FeatureSerializer):
         return reverse('feature-detail',
                        args=(obj.layer_id, obj.identifier))
 
+    def get_relations(self, obj):
+        return {
+            relation.name: reverse('feature-relation',
+                                   args=(obj.layer_id, obj.identifier, relation.pk))
+            for relation in obj.layer.relations_as_origin.all()
+            if hasattr(relation.destination, 'crud_view')
+        }
+
     class Meta(FeatureSerializer.Meta):
         exclude = ('source', 'target', 'layer', 'geom')
         fields = None
@@ -275,6 +283,14 @@ class CrudFeatureDetailSerializer(BaseUpdatableMixin, FeatureSerializer):
     pictures = serializers.SerializerMethodField()
     geometries = serializers.SerializerMethodField()
 
+    def get_relations(self, obj):
+        return {
+            relation.name: reverse('feature-relation',
+                                   args=(obj.layer_id, obj.identifier, relation.pk))
+            for relation in obj.layer.relations_as_origin.all()
+            if hasattr(relation.destination, 'crud_view')
+        }
+
     def get_pictures(self, obj):
         """ Return feature linked pictures grouped by category, with urls to create / replace / delete """
         return [{
@@ -341,7 +357,8 @@ class CrudFeatureDetailSerializer(BaseUpdatableMixin, FeatureSerializer):
                 prop.key: obj.properties.get(prop.key)
                 for prop in remained_properties
             }
-            properties = serialize_group_properties(obj, final_properties)
+            editable = {prop.key: prop.editable for prop in remained_properties}
+            properties = serialize_group_properties(obj, final_properties, editable)
 
             results['__default__'] = {
                 "title": "",
